@@ -14,5 +14,5 @@
 
 import logging
 
-logging.basicConfig(format="%(asctime)s %(levelname)s %(name)s %(funcName)s: %(message)s", datefmt="%Y-%m-%d %H:%M:%S")
-logger = logging.getLogger("[IAM-Python-SDK]")
+logging.basicConfig(format="%(asctime)s %(levelname)s [%(name)s:%(filename)s] %(funcName)s: %(message)s", datefmt="%Y-%m-%d %H:%M:%S %z")
+logger = logging.getLogger("IAM-Python-SDK")
